@@ -10,5 +10,5 @@ migrate = Migrate()
 def initialize(app):
     db.init_app(app)
     migrate.init_app(app, db)
-    db.create_all()
+    db.create_all(app=app)
     pre_seed(app)
